[![codecov](https://codecov.io/gh/pactus-project/pactus/branch/main/graph/badge.svg?token=8N6N60D5UI)](https://codecov.io/gh/pactus-project/pactus)
[![Go Report Card](https://goreportcard.com/badge/github.com/pactus-project/pactus)](https://goreportcard.com/report/github.com/pactus-project/pactus)
[![Discord](https://badgen.net/badge/icon/discord?icon=discord&label)](https://discord.gg/zPqWqV85ch)

------

# Pactus Blockchain

A full-node implementation of the Pactus blockchain in Go.

## Install

Please check the [install](./docs/install.md) document to build and run the Pactus blockchain.

## Contribution

Contributions to the Pactus blockchain are appreciated.
Please read the [CONTRIBUTING](./CONTRIBUTING.md) guidelines before submitting a pull request or opening an issue.

## License

The Pactus blockchain is under MIT [license](./LICENSE).

